@@ -59,7 +59,7 @@ class Dependency:
         print('PS: to remove the "Dependency" feature, just replace .add by .delete')
         return self.manager.get_path(current_file)
 
-    def delete(self, path=None, all=False, debug=False):
+    def delete(self, path=None, all=True, debug=False):
         if self.manager.is_production():
             print("No delete done, you are in production\n")
             return
@@ -67,4 +67,4 @@ class Dependency:
         self.manager.del_prod({"type": self.role, "path": current_file}, debug)
         print("🗑 Done! Your Dependency has been remove from production.\n")
         if all is True:
-            self.clear(path)
+            self.clear(current_file, "all")
